summaryrefslogtreecommitdiff
path: root/Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp')
-rw-r--r--Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp b/Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp
index a90ae7841b..149baddc19 100644
--- a/Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp
+++ b/Userland/Applications/SpaceAnalyzer/TreeMapWidget.cpp
@@ -316,8 +316,8 @@ void TreeMapWidget::doubleclick_event(GUI::MouseEvent& event)
void TreeMapWidget::mousewheel_event(GUI::MouseEvent& event)
{
- int delta = event.wheel_delta();
- // FIXME: The wheel_delta is premultiplied in the window server, we actually want a raw value here.
+ int delta = event.wheel_delta_y();
+ // FIXME: The wheel_delta_y is premultiplied in the window server, we actually want a raw value here.
int step_size = GUI::WindowServerConnection::the().get_scroll_step_size();
if (delta > 0) {
size_t step_back = delta / step_size;